@@ -15,23 +15,20 @@ unsafe impl Send for Node48 {}
 unsafe impl Sync for Node48 {}
 
 impl Node for Node48 {
-    fn new(prefix: &[u8]) -> *mut Self {
+    fn new(prefix: &[u8]) -> Box<Self> {
         let layout = alloc::Layout::from_size_align(
             std::mem::size_of::<Node48>(),
             std::mem::align_of::<Node48>(),
         )
         .unwrap();
-        let mem = unsafe {
+        let mut mem = unsafe {
             let mem = alloc::alloc_zeroed(layout) as *mut BaseNode;
             let base = BaseNode::new(NodeType::N48, prefix);
             mem.write(base);
-            mem as *mut Node48
+            Box::from_raw(mem as *mut Node48)
         };
-        {
-            let mem_ref = unsafe { &mut *mem };
-            for v in mem_ref.child_idx.iter_mut() {
-                *v = EMPTY_MARKER;
-            }
+        for v in mem.child_idx.iter_mut() {
+            *v = EMPTY_MARKER;
         }
         mem
     }
@@ -44,7 +41,7 @@ impl Node for Node48 {
         debug_assert!(self.get_child(k).is_none());
     }
 
-    fn get_children(&self, start: u8, end: u8) -> Result<(usize, Vec<(u8, *const BaseNode)>), ()> {
+    fn get_children(&self, start: u8, end: u8) -> Result<Vec<(u8, *const BaseNode)>, ()> {
         let mut children = Vec::with_capacity(24);
         let v = if let Ok(v) = self.base.read_lock() {
             v
@@ -65,7 +62,7 @@ impl Node for Node48 {
         if self.base.read_unlock(v).is_err() {
             return Err(());
         };
-        Ok((v, children))
+        Ok(children)
     }
 
     fn copy_to<N: Node>(&self, dst: &mut N) {
@@ -119,20 +116,4 @@ impl Node for Node48 {
             Some(self.children[self.child_idx[key as usize] as usize])
         }
     }
-
-    fn get_any_child(&self) -> *const BaseNode {
-        let mut any_child = std::ptr::null();
-
-        for i in 0..256 {
-            if self.child_idx[i] != EMPTY_MARKER {
-                let child = self.children[self.child_idx[i as usize] as usize];
-                if BaseNode::is_leaf(child) {
-                    return child;
-                } else {
-                    any_child = child;
-                }
-            }
-        }
-        any_child
-    }
 }
